import React from 'react';
import IMask from 'imask/esm/imask';
import { OutlineVariant, PropsWithMetadata } from '@highlight-ui/utils-commons';
import { MaskOptions, MaskEvent } from './imaskExports';
export declare type InputProps = PropsWithMetadata<{
    /** Allows providing a custom class name to the underlying HTML input element */
    inputClassName?: string;
    /** An [imaskjs](https://imask.js.org/guide.html) configuration object used for creating an IMask instance which will control the underlying HTML input element */
    maskOptions?: MaskOptions;
    /** Event fired on input when mask value has changed */
    onMaskAccept?: (e: MaskEvent) => void;
    /** Event fired when the value is completely filled */
    onMaskComplete?: (e: MaskEvent) => void;
    /** Sets the color of the input's border */
    outline?: OutlineVariant;
    /** The element to render on the left side of the input */
    prefix?: React.ReactNode;
    /** Style to apply to the prefix element's container */
    prefixVariant?: 'opaque' | 'transparent';
    /** The element to render on the right side of the input */
    suffix?: React.ReactNode;
}> & Omit<React.ComponentPropsWithoutRef<'input'>, 'prefix'>;
declare const Input: React.ForwardRefExoticComponent<{
    /** Allows providing a custom class name to the underlying HTML input element */
    inputClassName?: string | undefined;
    /** An [imaskjs](https://imask.js.org/guide.html) configuration object used for creating an IMask instance which will control the underlying HTML input element */
    maskOptions?: IMask.AnyMaskedOptions | undefined;
    /** Event fired on input when mask value has changed */
    onMaskAccept?: ((e: MaskEvent) => void) | undefined;
    /** Event fired when the value is completely filled */
    onMaskComplete?: ((e: MaskEvent) => void) | undefined;
    /** Sets the color of the input's border */
    outline?: OutlineVariant | undefined;
    /** The element to render on the left side of the input */
    prefix?: React.ReactNode;
    /** Style to apply to the prefix element's container */
    prefixVariant?: "opaque" | "transparent" | undefined;
    /** The element to render on the right side of the input */
    suffix?: React.ReactNode;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & Omit<Pick<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "key" | keyof React.InputHTMLAttributes<HTMLInputElement>>, "prefix"> & React.RefAttributes<HTMLInputElement>>;
export default Input;
